==> open-xchange-admin_7.8.2.orig.tar.bz2: open-xchange-admin-7.8.2/com.openexchange.admin/src/com/openexchange/admin/osgi/FilestoreLocationUpdaterRegistry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.admin.osgi;

import java.util.Collection;
import java.util.Queue;
import java.util.concurrent.ConcurrentLinkedQueue;
import com.openexchange.groupware.filestore.FileLocationHandler;


/**
 * {@link FilestoreLocationUpdaterRegistry}
 *
 * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
 * @since 7.6.0
 */
public class FilestoreLocationUpdaterRegistry {

    private static final FilestoreLocationUpdaterRegistry INSTANCE = new FilestoreLocationUpdaterRegistry();

    /**
     * Gets the instance
     *
     * @return The instance
     */
    public static FilestoreLocationUpdaterRegistry getInstance() {
        return INSTANCE;
    }

    // ---------------------------------------------------------------------------------------------------------

    private final Queue<FileLocationHandler> services;

    /**
     * Initializes a new {@link FilestoreLocationUpdaterRegistry}.
     */
    private FilestoreLocationUpdaterRegistry() {
        this.services = new ConcurrentLinkedQueue<FileLocationHandler>();
    }

    /**
     * Adds specified location handler.
     *
     * @param locationhandler The location handler to add
     */
    public void addService(FileLocationHandler locationhandler) {
        if (null != locationhandler) {
            services.offer(locationhandler);
        }
    }

    /**
     * Gets the currently available location handlers.
     *
     * @return The location handlers
     */
    public Collection<FileLocationHandler> getServices() {
        return services;
    }

}

==> open-xchange-admin_7.10.4.orig.tar.bz2: open-xchange-admin-7.10.4/com.openexchange.admin/src/com/openexchange/admin/osgi/FilestoreLocationUpdaterRegistry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.admin.osgi;

import java.util.Collection;
import java.util.Queue;
import java.util.concurrent.ConcurrentLinkedQueue;
import com.openexchange.groupware.filestore.FileLocationHandler;


/**
 * {@link FilestoreLocationUpdaterRegistry}
 *
 * @author <a href="mailto:jan.bauerdick@open-xchange.com">Jan Bauerdick</a>
 * @since 7.6.0
 */
public class FilestoreLocationUpdaterRegistry {

    private static final FilestoreLocationUpdaterRegistry INSTANCE = new FilestoreLocationUpdaterRegistry();

    /**
     * Gets the instance
     *
     * @return The instance
     */
    public static FilestoreLocationUpdaterRegistry getInstance() {
        return INSTANCE;
    }

    // ---------------------------------------------------------------------------------------------------------

    private final Queue<FileLocationHandler> services;

    /**
     * Initializes a new {@link FilestoreLocationUpdaterRegistry}.
     */
    private FilestoreLocationUpdaterRegistry() {
        this.services = new ConcurrentLinkedQueue<FileLocationHandler>();
    }

    /**
     * Adds specified location handler.
     *
     * @param locationhandler The location handler to add
     */
    public void addService(FileLocationHandler locationhandler) {
        if (null != locationhandler) {
            services.offer(locationhandler);
        }
    }

    /**
     * Removes specified location handler.
     *
     * @param locationhandler The location handler to remove
     */
    public void removeService(FileLocationHandler locationhandler) {
        if (null != locationhandler) {
            services.remove(locationhandler);
        }
    }

    /**
     * Gets the currently available location handlers.
     *
     * @return The location handlers
     */
    public Collection<FileLocationHandler> getServices() {
        return services;
    }

}
